Yog logging — lightweight logging macros with a consistent [yog] format.
The macros forward to [log], which does the formatting. Because they expand
to a single call that only formats its arguments when actually invoked, there
is no cost at a call site that is compiled out or behind a disabled level.
yog_logging::info!("loaded {} mods", 3);
yog_logging::warn!("slow tick: {}ms", 51);
yog_logging::error!("failed: {}", "boom");Macros
Enums
- Level
- Severity of a log record.